@@ -22,17 +22,17 @@
     <message>
         <location filename="../treewindow.ui" line="76"/>
         <source>All properties</source>
-        <translation type="unfinished"></translation>
+        <translation>Todas as propriedades</translation>
     </message>
     <message>
         <location filename="../treewindow.ui" line="101"/>
         <source>Type</source>
-        <translation type="unfinished"></translation>
+        <translation>Tipo</translation>
     </message>
     <message>
         <location filename="../treewindow.ui" line="106"/>
         <source>String value</source>
-        <translation type="unfinished"></translation>
+        <translation>Valor string</translation>
     </message>
 </context>
 </TS>
