@@ -4,36 +4,37 @@
 <context>
     <name>LXQtQuickLaunch</name>
     <message>
-        <location filename="../lxqtquicklaunch.cpp" line="219"/>
+        <location filename="../lxqtquicklaunch.cpp" line="214"/>
         <source>Drop Error</source>
         <translation>Erro ao largar</translation>
     </message>
     <message>
-        <location filename="../lxqtquicklaunch.cpp" line="220"/>
+        <location filename="../lxqtquicklaunch.cpp" line="215"/>
         <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
-        <translation>Neste momento, não pode incluir o ficheiro/url &apos;%1&apos; no inicio rápido.</translation>
+        <translation>Por agora, não pode incluir o ficheiro/URL &apos;%1&apos; no início rápido</translation>
     </message>
     <message>
-        <location filename="../lxqtquicklaunch.cpp" line="327"/>
+        <location filename="../lxqtquicklaunch.cpp" line="321"/>
         <source>Drop application
 icons here</source>
-        <translation type="unfinished"></translation>
+        <translation>Largue aqui os
+ícones das aplicações</translation>
     </message>
 </context>
 <context>
     <name>QuickLaunchButton</name>
-    <message>
-        <location filename="../quicklaunchbutton.cpp" line="52"/>
-        <source>Move left</source>
-        <translation>Mover para a esquerda</translation>
-    </message>
     <message>
         <location filename="../quicklaunchbutton.cpp" line="55"/>
-        <source>Move right</source>
-        <translation>Mover para a direita</translation>
+        <source>Move left</source>
+        <translation>Mover à esquerda</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="59"/>
+        <location filename="../quicklaunchbutton.cpp" line="58"/>
+        <source>Move right</source>
+        <translation>Mover à direita</translation>
+    </message>
+    <message>
+        <location filename="../quicklaunchbutton.cpp" line="62"/>
         <source>Remove from quicklaunch</source>
         <translation>Remover do inicio rápido</translation>
     </message>
